Ext.namespace('dSS11', 'dSS');

dSS11.StatusBarImpl = Ext.extend(Ext.Toolbar,
    {
        initComponent: function()
        {
            this.addEvents('refreshview', 'switchview');
            this.activeMessageId = 0;
            this.clearDelay = 10000;

            Ext.apply(this, {
                height: 30,
                layout: 'hbox',
                layoutConfig: {
                    align : 'stretch',
                    pack  : 'start'
                },
                bubbleEvents: [ 'switchview', 'refreshview' ],
                items:
                [
                    {
                        xtype: 'tbspacer',
                        width: 2
                    },
                    {
                        xtype: 'tbtext',
                        cls: 'x-black-text x-text-align-left x-text-cut',
                        ref: 'version',
                        width: 90
                    },
                    {
                        xtype: 'tbseparator',
                        width: 12
                    },
                    {
                        xtype: 'tbtext',
                        cls: 'x-black-text x-text-align-left x-text-cut',
                        ref: 'message',
                        flex: 4
                    },
                    {
                        xtype: 'tbseparator',
                        width: 12
                    },
                    {
                        xtype: 'button',
                        ref: 'refresh',
                        iconCls: 'icon-refresh-view',
                        handler: this.refreshPressed.createDelegate(this)
                    },
                    {
                        xtype: 'tbseparator',
                        width: 8
                    },
                    {
                        xtype: 'button',
                        ref: 'viewmode',
                        enableToggle: true,
                        iconCls: 'icon-advanced-view',
                        cls: 'btn-text-left',
                        width: 145,
                        disabled: true,
                        hidden: true,
                        listeners: {
                            toggle: this.viewModeChanged.createDelegate(this)
                        }
                    }
                ]
            });

            dSS11.StatusBarImpl.superclass.initComponent.apply(this, arguments);

            // it seems status bar was initialized before langpack was loaded
            // so make sure to set translated strings
            this.on('afterrender', function() {
                    this.viewmode.setText(_("Advanced view"));
                    this.viewmode.setVisible(true);
                    this.viewmode.enable();
                    this.refresh.setText(_("Refresh view"));
                    this.refresh.setVisible(true);
                    this.refresh.enable();
                },
                this);

            // don't ask me why but this was the only way how I could get a
            // regular tooltip to show up
            //
            // qtip was rendering over the button and blocking the button click,
            // so I had to go for a regular tooltip that allows some positioning
            // configuration
            this.on('afterrender', function() {
                    this.addTip.defer(1500, this);

                    if (dSS11.config.dSSIntegration === true)  {
                        dSS.MessageBus.on('statusmessage',
                            this.setMessage.createDelegate(this), this);
                    }

                    if (dSS11.config.dSAIntegration === true)  {
                        dSA.MessageBus.on('statusmessage',
                            this.setMessage.createDelegate(this), this);
                    }
                },
                this);

        },
        clearMessage: function(msgID) {
            if (this.activeMessageId !== msgID) {
                return;
            }

            this.message.el.fadeOut({
                remove: false,
                useDisplay: true,
                scope: this,
                callback: function(){
                    this.message.setText('&nbsp;');
                    this.message.el.show();
                }
            });
        },
        addTip: function() {
            var tip = new Ext.ToolTip({
                html: _("Refresh view"),
                anchor: 'top',
                draggable: false,
                target: this.refresh.el
            });
            this.refresh.setTooltip(tip);

            tip = new Ext.ToolTip({
                html: _("Switch between basic and advanced view"),
                anchor: 'top',
                maxWidth: 500,
                draggable: false,
                target: this.viewmode.el
            });
            this.viewmode.setTooltip(tip);
        },
        viewModeChanged: function(button, state) {
            // switch to advanced view
            if (state === true) {
                button.setText(_("Basic view"));
                button.setIconClass('icon-default-view');
                this.setMessage(_("Switched to advanced view"));
            } else {
                button.setText(_("Advanced view"));
                button.setIconClass('icon-advanced-view');
                this.setMessage(_("Switched to basic view"));
            }

            this.fireEvent('switchview', state);
        },
        refreshPressed: function() {
            this.fireEvent('refreshview');
        },
        setVersion: function(version) {
            this.version.setText(version);
            if (this.vTip !== undefined) {
                this.vTip.destroy();
            }

            this.vTip = new Ext.ToolTip({
                html: version,
                anchor: 'top',
                anchorToTarget: false,
                draggable: false,
                maxWidth: 380,
                title: _("Version"),
                target: this.version.getEl()
            });
        },
        setMessage: function(message) {
            this.activeMessageId++;
            this.message.setText(message);
            this.clearMessage.defer(this.clearDelay, this,
                                    [this.activeMessageId]);
        },
        showAdvancedView: function() {
            this.viewmode.toggle(true);
            this.viewmode.fireEvent('toggle', this.viewmode, true);
        }
    }
);

dSS11.StatusBar = (function() {
    return new dSS11.StatusBarImpl();
})();

